# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`java_ks::config`](#java_ksconfig): java_ks configuration

### Resource types

* [`java_ks`](#java_ks): Manages the entries in a java keystore, and uses composite namevars to accomplish the same alias spread across multiple target keystores.

## Classes

### <a name="java_ksconfig"></a>`java_ks::config`

java_ks configuration

#### Parameters

The following parameters are available in the `java_ks::config` class:

* [`params`](#params)

##### <a name="params"></a>`params`

Data type: `Any`



Default value: `{}`

## Resource types

### <a name="java_ks"></a>`java_ks`

Manages the entries in a java keystore, and uses composite namevars to
accomplish the same alias spread across multiple target keystores.

#### Properties

The following properties are available in the `java_ks` type.

##### `ensure`

Valid values: `present`, `absent`, `latest`

Has three states: present, absent, and latest.  Latest
will compare the on disk SHA1 fingerprint of the certificate to that
in keytool to determine if insync? returns true or false.  We redefine
insync? for this parameter to accomplish this.

Default value: `present`

#### Parameters

The following parameters are available in the `java_ks` type.

* [`certificate`](#certificate)
* [`chain`](#chain)
* [`destkeypass`](#destkeypass)
* [`keytool_timeout`](#keytool_timeout)
* [`name`](#name)
* [`password`](#password)
* [`password_fail_reset`](#password_fail_reset)
* [`password_file`](#password_file)
* [`path`](#path)
* [`private_key`](#private_key)
* [`private_key_type`](#private_key_type)
* [`provider`](#provider)
* [`source_alias`](#source_alias)
* [`source_password`](#source_password)
* [`storetype`](#storetype)
* [`target`](#target)
* [`trustcacerts`](#trustcacerts)

##### <a name="certificate"></a>`certificate`

A server certificate, followed by zero or more intermediate certificate authorities.
All certificates will be placed in the keystore.  This will autorequire the specified file.

##### <a name="chain"></a>`chain`

The intermediate certificate authorities, if they are to be taken
from a file separate from the server certificate. This will autorequire the specified file.

##### <a name="destkeypass"></a>`destkeypass`

The password used to protect the key in keystore.

##### <a name="keytool_timeout"></a>`keytool_timeout`

Timeout for the keytool command in seconds.

Default value: `120`

##### <a name="name"></a>`name`

namevar

The alias that is used to identify the entry in the keystore. This will be
converted to lowercase.

##### <a name="password"></a>`password`

The password used to protect the keystore.  If private keys are
subsequently also protected this password will be used to attempt
unlocking. Must be six or more characters in length. Cannot be used
together with :password_file, but you must pass at least one of these parameters.

##### <a name="password_fail_reset"></a>`password_fail_reset`

Valid values: ``true``, ``false``

If the supplied password does not succeed in unlocking the
keystore file, then delete the keystore file and create a new one.
Default: false.

Default value: ``false``

##### <a name="password_file"></a>`password_file`

The path to a file containing the password used to protect the
keystore. This cannot be used together with :password, but you must pass at least one of these parameters.

##### <a name="path"></a>`path`

The search path used for command (keytool, openssl) execution.
Paths can be specified as an array or as a '

##### <a name="private_key"></a>`private_key`

If you want an application to be a server and encrypt traffic,
you will need a private key.  Private key entries in a keystore must be
accompanied by a signed certificate for the keytool provider. This will autorequire the specified file.

##### <a name="private_key_type"></a>`private_key_type`

Valid values: `rsa`, `dsa`, `ec`

The type of the private key. Usually the private key is of type RSA
key but it can also be an Elliptic Curve key (EC) or DSA.
Valid options: <rsa>, <dsa>, <ec>. Defaults to <rsa>

Default value: `rsa`

##### <a name="provider"></a>`provider`

The specific backend to use for this `java_ks` resource. You will seldom need to specify this --- Puppet will usually
discover the appropriate provider for your platform.

##### <a name="source_alias"></a>`source_alias`

The source certificate alias

##### <a name="source_password"></a>`source_password`

The source keystore password

##### <a name="storetype"></a>`storetype`

Valid values: `jceks`, `pkcs12`, `jks`

Optional storetype
Valid options: <jceks>, <pkcs12>, <jks>

##### <a name="target"></a>`target`

namevar

Destination file for the keystore.  This will autorequire the parent directory of the file.

##### <a name="trustcacerts"></a>`trustcacerts`

Valid values: ``true``, ``false``

Certificate authorities aren't by default trusted so if you are adding a CA you need to set this to true.
Defaults to :false.

Default value: ``false``

